FileProcessorVisitor

Trait FileProcessorVisitor 

pub trait FileProcessorVisitor: Default {
    type Visitor;

    // Provided methods
    fn process(
        &self,
        _context: &Context,
        _file_set: &mut FileSet,
        _visitor: &Self::Visitor,
    ) { ... }
    fn post_process(
        &self,
        _context: &Context,
        _file_set: &mut FileSet,
        _visitor: &Self::Visitor,
    ) { ... }
}
File processor visitor.

Required Associated Types

type Visitor

Visitor’s type.

Provided Methods

fn process( &self, _context: &Context, _file_set: &mut FileSet, _visitor: &Self::Visitor, )

Processor executed while visiting the current element and before visiting its children.

fn post_process( &self, _context: &Context, _file_set: &mut FileSet, _visitor: &Self::Visitor, )

Post-processor executed after visiting the current element and its children. It has a special behavior for ParameterVisitor: It only executes if the parameter isn’t the last parameter, which is useful for writing separators.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors