pub trait FileProcessorVisitor: Default {
type Visitor;
// Provided methods
fn process(
&self,
_context: &Context,
_file_set: &mut FileSet,
_visitor: &Self::Visitor,
) { ... }
fn post_process(
&self,
_context: &Context,
_file_set: &mut FileSet,
_visitor: &Self::Visitor,
) { ... }
}Expand description
File processor visitor.
Required Associated Types
Provided Methods
Sourcefn process(
&self,
_context: &Context,
_file_set: &mut FileSet,
_visitor: &Self::Visitor,
)
fn process( &self, _context: &Context, _file_set: &mut FileSet, _visitor: &Self::Visitor, )
Processor executed while visiting the current element and before visiting its children.
Sourcefn post_process(
&self,
_context: &Context,
_file_set: &mut FileSet,
_visitor: &Self::Visitor,
)
fn post_process( &self, _context: &Context, _file_set: &mut FileSet, _visitor: &Self::Visitor, )
Post-processor executed after visiting the current element and its children.
It has a special behavior for ParameterVisitor: It only executes if the parameter isn’t
the last parameter, which is useful for writing separators.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.